@@ -23,11 +23,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
+import aws_cdk.core
+
 
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD"):
@@ -38,7 +37,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
     cloudformationResource:
     :cloudformationResource:: AWS::DirectoryService::MicrosoftAD
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, password: str, vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable], create_alias: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, short_name: typing.Optional[str]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, password: str, vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
         """Create a new ``AWS::DirectoryService::MicrosoftAD``.
 
         :param scope: - scope in which this resource is defined.
@@ -132,7 +131,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -146,7 +145,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "password")
 
     @password.setter
-    def password(self, value: str):
+    def password(self, value: str) -> None:
         jsii.set(self, "password", value)
 
     @builtins.property
@@ -160,12 +159,12 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "vpcSettings")
 
     @vpc_settings.setter
-    def vpc_settings(self, value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]):
+    def vpc_settings(self, value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]) -> None:
         jsii.set(self, "vpcSettings", value)
 
     @builtins.property
     @jsii.member(jsii_name="createAlias")
-    def create_alias(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
@@ -174,7 +173,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "createAlias")
 
     @create_alias.setter
-    def create_alias(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def create_alias(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "createAlias", value)
 
     @builtins.property
@@ -188,12 +187,12 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "edition")
 
     @edition.setter
-    def edition(self, value: typing.Optional[str]):
+    def edition(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "edition", value)
 
     @builtins.property
     @jsii.member(jsii_name="enableSso")
-    def enable_sso(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
         see
@@ -202,7 +201,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "enableSso")
 
     @enable_sso.setter
-    def enable_sso(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def enable_sso(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "enableSso", value)
 
     @builtins.property
@@ -216,7 +215,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "shortName")
 
     @short_name.setter
-    def short_name(self, value: typing.Optional[str]):
+    def short_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "shortName", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD.VpcSettingsProperty", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
@@ -265,7 +264,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftADProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'password': 'password', 'vpc_settings': 'vpcSettings', 'create_alias': 'createAlias', 'edition': 'edition', 'enable_sso': 'enableSso', 'short_name': 'shortName'})
 class CfnMicrosoftADProps():
-    def __init__(self, *, name: str, password: str, vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable], create_alias: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, short_name: typing.Optional[str]=None) -> None:
+    def __init__(self, *, name: str, password: str, vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
         """Properties for defining a ``AWS::DirectoryService::MicrosoftAD``.
 
         :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
@@ -317,7 +316,7 @@ class CfnMicrosoftADProps():
         return self._values.get('vpc_settings')
 
     @builtins.property
-    def create_alias(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
@@ -335,7 +334,7 @@ class CfnMicrosoftADProps():
         return self._values.get('edition')
 
     @builtins.property
-    def enable_sso(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
         see
@@ -371,7 +370,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
     cloudformationResource:
     :cloudformationResource:: AWS::DirectoryService::SimpleAD
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, password: str, size: str, vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"], create_alias: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, short_name: typing.Optional[str]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, password: str, size: str, vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
         """Create a new ``AWS::DirectoryService::SimpleAD``.
 
         :param scope: - scope in which this resource is defined.
@@ -466,7 +465,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -480,7 +479,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "password")
 
     @password.setter
-    def password(self, value: str):
+    def password(self, value: str) -> None:
         jsii.set(self, "password", value)
 
     @builtins.property
@@ -494,7 +493,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "size")
 
     @size.setter
-    def size(self, value: str):
+    def size(self, value: str) -> None:
         jsii.set(self, "size", value)
 
     @builtins.property
@@ -508,12 +507,12 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "vpcSettings")
 
     @vpc_settings.setter
-    def vpc_settings(self, value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]):
+    def vpc_settings(self, value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]) -> None:
         jsii.set(self, "vpcSettings", value)
 
     @builtins.property
     @jsii.member(jsii_name="createAlias")
-    def create_alias(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
@@ -522,7 +521,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "createAlias")
 
     @create_alias.setter
-    def create_alias(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def create_alias(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "createAlias", value)
 
     @builtins.property
@@ -536,12 +535,12 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
     @jsii.member(jsii_name="enableSso")
-    def enable_sso(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
         see
@@ -550,7 +549,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "enableSso")
 
     @enable_sso.setter
-    def enable_sso(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def enable_sso(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "enableSso", value)
 
     @builtins.property
@@ -564,7 +563,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "shortName")
 
     @short_name.setter
-    def short_name(self, value: typing.Optional[str]):
+    def short_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "shortName", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleAD.VpcSettingsProperty", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
@@ -613,7 +612,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleADProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'password': 'password', 'size': 'size', 'vpc_settings': 'vpcSettings', 'create_alias': 'createAlias', 'description': 'description', 'enable_sso': 'enableSso', 'short_name': 'shortName'})
 class CfnSimpleADProps():
-    def __init__(self, *, name: str, password: str, size: str, vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"], create_alias: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, short_name: typing.Optional[str]=None) -> None:
+    def __init__(self, *, name: str, password: str, size: str, vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
         """Properties for defining a ``AWS::DirectoryService::SimpleAD``.
 
         :param name: ``AWS::DirectoryService::SimpleAD.Name``.
@@ -676,7 +675,7 @@ class CfnSimpleADProps():
         return self._values.get('vpc_settings')
 
     @builtins.property
-    def create_alias(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
@@ -694,7 +693,7 @@ class CfnSimpleADProps():
         return self._values.get('description')
 
     @builtins.property
-    def enable_sso(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
         see
